==> halkyon-annotations-0.8.2.redhat-00001-sources.jar: io/dekorate/halkyon/model/ComponentListFluentImpl.java <==
package io.dekorate.halkyon.model;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.deps.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.deps.javax.validation.constraints.NotNull;
import io.dekorate.deps.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.dekorate.deps.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.dekorate.deps.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import io.dekorate.deps.javax.validation.Valid;
import java.util.Collection;
import java.lang.Object;

public class ComponentListFluentImpl<A extends ComponentListFluent<A>> extends BaseFluent<A> implements ComponentListFluent<A>{

    private String apiVersion;
    private java.util.List<ComponentBuilder> items;
    private String kind;
    private ListMeta metadata;

    public ComponentListFluentImpl(){
    }
    public ComponentListFluentImpl(ComponentList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,Component item){
            if (this.items == null) {this.items = new ArrayList<ComponentBuilder>();}
            ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,Component item){
            if (this.items == null) {this.items = new ArrayList<ComponentBuilder>();}
            ComponentBuilder builder = new ComponentBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(Component... items){
            if (this.items == null) {this.items = new ArrayList<ComponentBuilder>();}
            for (Component item : items) {ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<Component> items){
            if (this.items == null) {this.items = new ArrayList<ComponentBuilder>();}
            for (Component item : items) {ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(Component... items){
            for (Component item : items) {ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<Component> items){
            for (Component item : items) {ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<ComponentBuilder> predicate){
            if (items == null) return (A) this;
            final Iterator<ComponentBuilder> each = items.iterator();
            final List visitables = _visitables.get("items");
            while (each.hasNext()) {
              ComponentBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<Component> getItems(){
            return build(items);
    }

    public java.util.List<Component> buildItems(){
            return build(items);
    }

    public Component buildItem(int index){
            return this.items.get(index).build();
    }

    public Component buildFirstItem(){
            return this.items.get(0).build();
    }

    public Component buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public Component buildMatchingItem(Predicate<ComponentBuilder> predicate){
            for (ComponentBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<ComponentBuilder> predicate){
            for (ComponentBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(java.util.List<Component> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<ComponentBuilder>(); for (Component item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(Component... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (Component item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public ComponentListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public ComponentListFluent.ItemsNested<A> addNewItemLike(Component item){
            return new ItemsNestedImpl(-1, item);
    }

    public ComponentListFluent.ItemsNested<A> setNewItemLike(int index,Component item){
            return new ItemsNestedImpl(index, item);
    }

    public ComponentListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public ComponentListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public ComponentListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public ComponentListFluent.ItemsNested<A> editMatchingItem(Predicate<ComponentBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ComponentListFluentImpl that = (ComponentListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends ComponentFluentImpl<ComponentListFluent.ItemsNested<N>> implements ComponentListFluent.ItemsNested<N>,Nested<N>{

            private final ComponentBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,Component item){
                    this.index = index;
                    this.builder = new ComponentBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new ComponentBuilder(this);
            }
    
    public N and(){
            return (N) ComponentListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}

==> halkyon-annotations-0.10.10.redhat-00001-sources.jar: io/dekorate/halkyon/model/ComponentListFluentImpl.java <==
package io.dekorate.halkyon.model;

import io.dekorate.deps.kubernetes.api.builder.VisitableBuilder;
import io.dekorate.deps.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.dekorate.deps.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.dekorate.deps.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.dekorate.deps.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class ComponentListFluentImpl<A extends ComponentListFluent<A>> extends BaseFluent<A> implements ComponentListFluent<A>{

    private String apiVersion;
    private List<ComponentBuilder> items;
    private String kind;
    private ListMeta metadata;

    public ComponentListFluentImpl(){
    }
    public ComponentListFluentImpl(ComponentList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,Component item){
            if (this.items == null) {this.items = new ArrayList<ComponentBuilder>();}
            ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,Component item){
            if (this.items == null) {this.items = new ArrayList<ComponentBuilder>();}
            ComponentBuilder builder = new ComponentBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(Component... items){
            if (this.items == null) {this.items = new ArrayList<ComponentBuilder>();}
            for (Component item : items) {ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<Component> items){
            if (this.items == null) {this.items = new ArrayList<ComponentBuilder>();}
            for (Component item : items) {ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(Component... items){
            for (Component item : items) {ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<Component> items){
            for (Component item : items) {ComponentBuilder builder = new ComponentBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<ComponentBuilder> predicate){
            if (items == null) return (A) this;
            final Iterator<ComponentBuilder> each = items.iterator();
            final List visitables = _visitables.get("items");
            while (each.hasNext()) {
              ComponentBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Component> getItems(){
            return build(items);
    }

    public List<Component> buildItems(){
            return build(items);
    }

    public Component buildItem(int index){
            return this.items.get(index).build();
    }

    public Component buildFirstItem(){
            return this.items.get(0).build();
    }

    public Component buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public Component buildMatchingItem(Predicate<ComponentBuilder> predicate){
            for (ComponentBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<ComponentBuilder> predicate){
            for (ComponentBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(List<Component> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<ComponentBuilder>(); for (Component item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(Component... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (Component item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public ComponentListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public ComponentListFluent.ItemsNested<A> addNewItemLike(Component item){
            return new ItemsNestedImpl(-1, item);
    }

    public ComponentListFluent.ItemsNested<A> setNewItemLike(int index,Component item){
            return new ItemsNestedImpl(index, item);
    }

    public ComponentListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public ComponentListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public ComponentListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public ComponentListFluent.ItemsNested<A> editMatchingItem(Predicate<ComponentBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ComponentListFluentImpl that = (ComponentListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends ComponentFluentImpl<ComponentListFluent.ItemsNested<N>> implements ComponentListFluent.ItemsNested<N>,Nested<N>{

            private final ComponentBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,Component item){
                    this.index = index;
                    this.builder = new ComponentBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new ComponentBuilder(this);
            }
    
    public N and(){
            return (N) ComponentListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}
